@@ -380,7 +380,7 @@ def create_default_profile():
             f.close()
 
 
-def get_aws_access(url, user, password, duration_seconds):
+def get_aws_access(url, user, password, duration_seconds, profile='saml', role_arn=None):
     """
     this function has been created to call the aws access
     module in batch
@@ -388,13 +388,15 @@ def get_aws_access(url, user, password, duration_seconds):
     :user: The user id to connect to AWS
     :password: The password to connect to AWS
     :duration_seconds: Duration for which access is required.
+    :profile: AWS credentials config section profile name
+    :role_arn: to select specific role if it is having multiple roles
     The default duration is 1 hour
     """
 
     try:
         saml_assertion = get_saml_assertion(url, user, password)
         create_default_profile()
-        saml2AWS(saml_assertion, duration_seconds)
+        saml2AWS(saml_assertion, duration_seconds, profile, role_arn)
         return 0
     except Exception as e:
         track = traceback.format_exc()
@@ -437,11 +439,25 @@ if __name__ == "__main__":
             "Must be > 900 and less than 43200. Default is 12 hour or 43200 secs."),
         required=False)
 
+    parser.add_argument('--prf',
+                        dest='profile',
+                        type=str,
+                        help=("Specify profile name for aws credentials config, default will be saml"),
+                        required=False)
+
+    parser.add_argument('--r',
+                        dest='role_arn',
+                        type=str,
+                        help=("Specify Role ARN to select the specific role if it is mapped with multiple roles"),
+                        required=False)
+
     args = parser.parse_args()
 
     url = args.url
     user = args.user
     duration_seconds = args.duration_seconds
+    profile = args.profile
+    role_arn = args.role_arn
 
     if args.url is None:
         try:
@@ -497,7 +513,7 @@ if __name__ == "__main__":
         password = args.password
 
     try:
-        get_aws_access(url, user, password, duration_seconds)
+        get_aws_access(url, user, password, duration_seconds, profile, role_arn)
     except Exception:
         traceback.print_exc(file=sys.stdout)
     sys.exit(0)
